#pragma once
//  AppRunSettings
//
//  This class provides the Application Execution settings for the RDBCreate application
//
//  Message Identifier:      CDB
//  Message Range:           0001 - 0099
//  Trace area assignment:   None
//  Version:                 2.1.0  Build: 59
//
//  Version History:
//
//  Copyright: Hadleigh Marshall (Netherlands) b.v. 2007 - 2011
//
#include "../DXCommon/RunSettings.h"

//  Local Definitions

//  Application Trap Flags
#define		TRAP_PANIC_EOP		0x0001				//  Panic at the end of processing
#define		TRAP_DUMP_EOP		0x0002				//  MiniDump at end of processing

//  Information Messages
#define		MSG_CDB0053I		"CDB0053I: Logging level is set to %s."
#define		MSG_CDB0054I		"CDB0054I: This run will attempt to update the design of an existing database."

//  Error Messages
#define		MSG_CDB0050E		"CDB0050E: Control database name is missing."
#define		MSG_CDB0051E		"CDB0051E: Inavlid parameter '%s' has been ignored."
#define		MSG_CDB0052E		"CDB0052E: Inavlid switch '%s' has been ignored."

//  Unnumbered Messages

#define		MSG_USAGE1			"Usage:"
#define		MSG_USAGE2			"RDBCreate TargetServer TargetDbName ManifestURL [-V|T|D][-U]"
#define		MSG_USAGE3			"  TargetServer - Name of the server on which to create the database | 'Local'."
#define		MSG_USAGE4			"  TargetDbName - Name database to create (relative to the notes data directory)."
#define		MSG_USAGE5			"  ManifestURL - URL of the Design Manifest for this database."
#define		MSG_USAGE6			"  [-V]|[-T]|[-D] - Optional switch - Set logging level to Verbose, Trace or Debug."
#define		MSG_USAGE7			"  [-U] - Optional switch Update the design of an existing database."
#define		MSG_USAGE8			"  [-S] - Optional switch Sign the ndesign elements."
#define		MSG_USAGE9			"  [-Z:nnn] - Optional switch set traps in the mainline code."
#define		MSG_USAGE10			"Copyright: Hadleigh Marshall Netherlands 2008-2010."

class AppRunSettings :
	public RunSettings
{
public:
	//  Constructor
	AppRunSettings(int argc, char * argv[]);

	//  Destructor
	~AppRunSettings(void);

	//  Public Members
	char	szManifestURL[MAX_URL];						//  Remote Manifest URL
	int		iTraps;										//  Program Traps

private:
	//  Private Functions
	BOOL SetDefaults(void);								//  Set the application run defaults
	BOOL ValidateParameters(int argc, char * argv[]);	//  Validate Parameters
	void ShowUsage(void);								//  Show program usage
	void ShowSettings(void);							//  Show the current settings
};
